==> carbon-component-mapper-3.11.4.tgz: package/esm/switch/switch.js <==
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import Toggle from "carbon-components-react/es/components/Toggle/Toggle.js";
import prepareProps from '../prepare-props';
import HelperTextBlock from '../helper-text-block/helper-text-block';

var Switch = function Switch(props) {
  var _useFieldApi = useFieldApi(_objectSpread(_objectSpread({}, prepareProps(props)), {}, {
    type: 'checkbox'
  })),
      input = _useFieldApi.input,
      meta = _useFieldApi.meta,
      onText = _useFieldApi.onText,
      offText = _useFieldApi.offText,
      validateOnMount = _useFieldApi.validateOnMount,
      helperText = _useFieldApi.helperText,
      WrapperProps = _useFieldApi.WrapperProps,
      rest = _objectWithoutProperties(_useFieldApi, ["input", "meta", "onText", "offText", "validateOnMount", "helperText", "WrapperProps"]);

  var invalid = (meta.touched || validateOnMount) && (meta.error || meta.submitError);
  var warnText = (meta.touched || validateOnMount) && meta.warning;

  var checked = input.checked,
      inputRest = _objectWithoutProperties(input, ["checked"]);

  return /*#__PURE__*/React.createElement("div", WrapperProps, /*#__PURE__*/React.createElement(Toggle, _extends({}, inputRest, {
    toggled: checked,
    key: input.name,
    id: input.name,
    labelA: offText,
    labelB: onText
  }, rest)), /*#__PURE__*/React.createElement(HelperTextBlock, {
    helperText: helperText,
    errorText: invalid,
    warnText: warnText
  }));
};

Switch.propTypes = {
  isDisabled: PropTypes.bool,
  isReadOnly: PropTypes.bool,
  isRequired: PropTypes.bool,
  label: PropTypes.node,
  labelText: PropTypes.node,
  description: PropTypes.node,
  WrapperProps: PropTypes.object
};
export default Switch;

==> carbon-component-mapper-3.13.0.tgz: package/esm/switch/switch.js <==
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["input", "meta", "onText", "offText", "validateOnMount", "helperText", "WrapperProps"],
    _excluded2 = ["checked"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import Toggle from "carbon-components-react/es/components/Toggle/next/Toggle.js";
import prepareProps from '../prepare-props';
import HelperTextBlock from '../helper-text-block/helper-text-block';

var Switch = function Switch(props) {
  var _useFieldApi = useFieldApi(_objectSpread(_objectSpread({}, prepareProps(props)), {}, {
    type: 'checkbox'
  })),
      input = _useFieldApi.input,
      meta = _useFieldApi.meta,
      onText = _useFieldApi.onText,
      offText = _useFieldApi.offText,
      validateOnMount = _useFieldApi.validateOnMount,
      helperText = _useFieldApi.helperText,
      WrapperProps = _useFieldApi.WrapperProps,
      rest = _objectWithoutProperties(_useFieldApi, _excluded);

  var invalid = (meta.touched || validateOnMount) && (meta.error || meta.submitError);
  var warnText = (meta.touched || validateOnMount) && meta.warning;

  var checked = input.checked,
      inputRest = _objectWithoutProperties(input, _excluded2);

  return /*#__PURE__*/React.createElement("div", WrapperProps, /*#__PURE__*/React.createElement(Toggle, _extends({}, inputRest, {
    toggled: checked,
    key: input.name,
    id: input.name,
    labelA: offText,
    labelB: onText
  }, rest)), /*#__PURE__*/React.createElement(HelperTextBlock, {
    helperText: helperText,
    errorText: invalid,
    warnText: warnText
  }));
};

Switch.propTypes = {
  isDisabled: PropTypes.bool,
  isReadOnly: PropTypes.bool,
  isRequired: PropTypes.bool,
  label: PropTypes.node,
  labelText: PropTypes.node,
  description: PropTypes.node,
  WrapperProps: PropTypes.object
};
export default Switch;
